==> haskell-ed25519-0.0.5.0-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ed25519
version: 0.0.5.0
id: ed25519-0.0.5.0-J1zl42RyRuN3VNmQie6YiT
key: ed25519-0.0.5.0-J1zl42RyRuN3VNmQie6YiT
license: MIT
copyright: Copyright (c) Austin Seipp 2013-2015
maintainer: Austin Seipp <aseipp@pobox.com>
author: Austin Seipp
homepage: http://thoughtpolice.github.com/hs-ed25519
synopsis: Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.
category: Cryptography
abi: 1ba7abd7d31ea23498f23247335be7e2
exposed: True
exposed-modules:
    Crypto.Sign.Ed25519
import-dirs: /usr/lib/ghc-8.4.3/site-local/ed25519-0.0.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ed25519-0.0.5.0
hs-libraries: HSed25519-0.0.5.0-J1zl42RyRuN3VNmQie6YiT
depends:
    ghc-prim-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2
abi-depends: ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html: /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ed25519-0.0.5.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ed25519
version: 0.0.5.0
id: ed25519-0.0.5.0-7cQiDizyG7J2idP2c5u3U2
key: ed25519-0.0.5.0-7cQiDizyG7J2idP2c5u3U2
license: MIT
copyright: Copyright (c) Austin Seipp 2013-2015
maintainer: Austin Seipp <aseipp@pobox.com>
author: Austin Seipp
homepage: http://thoughtpolice.github.com/hs-ed25519
synopsis: Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.
category: Cryptography
abi: fe79e5f636bdaae40900cfe26310a843
exposed: True
exposed-modules:
    Crypto.Sign.Ed25519
import-dirs: /usr/lib/ghc-8.6.1/site-local/ed25519-0.0.5.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/ed25519-0.0.5.0
hs-libraries: HSed25519-0.0.5.0-7cQiDizyG7J2idP2c5u3U2
depends:
    base-4.12.0.0 bytestring-0.10.8.2 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html: /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
